@@ -1,23 +1,27 @@
 '''ffwrapper.py'''
 
+from __future__ import print_function
+
 # Internal Libraries
 import subprocess
 import os.path
 from platform import system
 
 # Included Libraries
-from auto_editor.usefulFunctions import pipeToConsole
+from auto_editor.utils.func import get_stdout
 
-def _set_path(dirpath, my_ffmpeg):
+def _set_ff_path(dirpath, ff_location, my_ffmpeg):
+    from platform import system
+    if(ff_location is not None):
+        return ff_location
     if(my_ffmpeg or system() not in ['Windows', 'Darwin']):
         return 'ffmpeg'
     program = 'ffmpeg' if system() == 'Darwin' else 'ffmpeg.exe'
     return os.path.join(dirpath, 'ffmpeg', system(), program)
 
-def _test_path(dirpath, my_ffmpeg, log):
-    path = _set_path(dirpath, my_ffmpeg)
+def _test_path(path, log):
     try:
-        pipeToConsole([path, '-h'])
+        get_stdout([path, '-h'])
     except FileNotFoundError:
         if(system() == 'Darwin'):
             log.error('No ffmpeg found, download via homebrew or restore the '\
@@ -32,15 +36,16 @@ def _test_path(dirpath, my_ffmpeg, log):
     return path
 
 class FFmpeg():
-    def __init__(self, dirpath, myFFmpeg, FFdebug, log):
+    def __init__(self, dirpath, ff_location, my_ffmpeg, debug, log):
+        _path = _set_ff_path(dirpath, ff_location, my_ffmpeg)
         self.log = log
-        self.path = _test_path(dirpath, myFFmpeg, log)
-        self.FFdebug = FFdebug
+        self.path = _test_path(_path, log)
+        self.FFdebug = debug
 
     def getPath(self):
         return self.path
 
-    def run(self, cmd: list):
+    def run(self, cmd):
         cmd = [self.path, '-y'] + cmd
         if(self.FFdebug):
             cmd.extend(['-hide_banner'])
@@ -74,7 +79,7 @@ class FFmpeg():
                 return match.groupdict()['match']
             return None
 
-        info = pipeToConsole([self.path, '-hide_banner', '-i', path])
+        info = get_stdout([self.path, '-hide_banner', '-i', path])
 
         setattr(file, 'duration', regex_match(r'Duration:\s(?P<match>[\d:.]+),', info))
         setattr(file, 'bitrate', regex_match(r'bitrate:\s(?P<match>\d+\skb\/s)', info))
@@ -88,11 +93,12 @@ class FFmpeg():
             if(re.search(r'Stream #', line)):
                 s_data = {}
                 if(re.search(r'Video:', line)):
-                    s_data['width'] = regex_match(r'(?P<match>\d+)x\d+\s', line)
-                    s_data['height'] = regex_match(r'\d+x(?P<match>\d+)\s', line)
+                    s_data['width'] = regex_match(r'(?P<match>\d+)x\d+[\s,]', line)
+                    s_data['height'] = regex_match(r'\d+x(?P<match>\d+)[\s,]', line)
                     s_data['codec'] = regex_match(r'Video:\s(?P<match>\w+)', line)
                     s_data['bitrate'] = regex_match(r'\s(?P<match>\d+\skb\/s)', line)
-                    fps = regex_match(r'\s(?P<match>[\d\.]+)\stbr', line)
+                    if(fps is None):
+                        fps = regex_match(r'\s(?P<match>[\d\.]+)\stbr', line)
                     video_streams.append(s_data)
 
                 elif(re.search(r'Audio:', line)):
@@ -109,7 +115,6 @@ class FFmpeg():
         setattr(file, 'video_streams', video_streams)
         setattr(file, 'audio_streams', audio_streams)
         setattr(file, 'subtitle_streams', subtitle_streams)
-
         return file
 
     def Popen(self, cmd):
@@ -123,7 +128,7 @@ class FFmpeg():
 
         if(self.FFdebug):
             print(cmd)
-        output = pipeToConsole(cmd)
+        output = get_stdout(cmd)
         if(self.FFdebug):
             print(output)
 
