@@ -1,25 +1,24 @@
-'''final_cut_pro.py'''
+'''formats/final_cut_pro.py'''
 
-from auto_editor.formats.utils import indent, get_width_height
+from .utils import indent, get_width_height
 
-def fcp_xml(inp, temp, output, clips, chunks, tracks, total_dur, sampleRate,
-    audioFile, fps, log):
+def fcp_xml(inp, temp, output, clips, tracks, total_dur, audioFile, fps, log):
 
     pathurl = 'file://' + inp.abspath
-    name = inp.name
+    name = inp.basename
 
-    def fraction(inp, fps) -> str:
+    def fraction(a, fps) -> str:
         from fractions import Fraction
 
-        if(inp == 0):
+        if(a == 0):
             return '0s'
 
-        if(isinstance(inp, float)):
-            inp = Fraction(inp)
+        if(isinstance(a, float)):
+            a = Fraction(a)
         if(isinstance(fps, float)):
             fps = Fraction(fps)
 
-        frac = Fraction(inp, fps).limit_denominator()
+        frac = Fraction(a, fps).limit_denominator()
         num = frac.numerator
         dem = frac.denominator
 
@@ -40,11 +39,11 @@ def fcp_xml(inp, temp, output, clips, chunks, tracks, total_dur, sampleRate,
         return '{}/{}s'.format(num, dem)
 
     width, height = get_width_height(inp)
+    if(width is None or height is None):
+        width, height = '1280', '720'
+    frame_duration = fraction(1, fps)
 
     with open(output, 'w', encoding='utf-8') as outfile:
-
-        frame_duration = fraction(1, fps)
-
         outfile.write('<?xml version="1.0" encoding="UTF-8"?>\n')
         outfile.write('<!DOCTYPE fcpxml>\n\n')
         outfile.write('<fcpxml version="1.9">\n')
@@ -53,11 +52,12 @@ def fcp_xml(inp, temp, output, clips, chunks, tracks, total_dur, sampleRate,
             'frameDuration="{}" width="{}" height="{}"'.format(frame_duration, width, height)+\
             ' colorSpace="1-1-1 (Rec. 709)"/>\n')
 
-        outfile.write('\t\t<asset id="r2" name="{}" start="0s" '.format(name)+\
-            'hasVideo="1" format="r1" hasAudio="1" '\
-            'audioSources="1" audioChannels="2" audioRate="{}">\n'.format(sampleRate))
+        outfile.write('\t\t<asset id="r2" name="{}" start="0s" '.format(name) +
+            'hasVideo="1" format="r1" hasAudio="1" ' +
+            'audioSources="1" audioChannels="2" duration="{}">\n'.format(
+                fraction(total_dur, fps)))
 
-        outfile.write('\t\t\t<media-rep kind="original-media" '.format()+\
+        outfile.write('\t\t\t<media-rep kind="original-media" ' +
             'src="{}"></media-rep>\n'.format(pathurl))
         outfile.write('\t\t</asset>\n')
         outfile.write('\t</resources>\n')
@@ -71,8 +71,7 @@ def fcp_xml(inp, temp, output, clips, chunks, tracks, total_dur, sampleRate,
         )
 
         last_dur = 0
-
-        for _, clip in enumerate(clips):
+        for clip in clips:
             clip_dur = (clip[1] - clip[0]) / (clip[2] / 100)
             dur = fraction(clip_dur, fps)
 
@@ -80,13 +79,13 @@ def fcp_xml(inp, temp, output, clips, chunks, tracks, total_dur, sampleRate,
 
             if(last_dur == 0):
                 outfile.write(indent(6, '<asset-clip name="{}" offset="0s" ref="r2"'.format(name)+\
-                ' duration="{}" audioRole="dialogue" tcFormat="NDF"{}>'.format(dur, close)))
+                ' duration="{}" tcFormat="NDF"{}>'.format(dur, close)))
             else:
                 start = fraction(clip[0] / (clip[2] / 100), fps)
                 off = fraction(last_dur, fps)
                 outfile.write(indent(6,
                     '<asset-clip name="{}" offset="{}" ref="r2" '.format(name, off)+\
-                    'duration="{}" start="{}" audioRole="dialogue" '.format(dur, start)+\
+                    'duration="{}" start="{}" '.format(dur, start)+\
                     'tcFormat="NDF"{}>'.format(close),
                 ))
 
