@@ -1,4 +1,4 @@
-'''json_cutlist.py'''
+'''formats/json_cutlist.py'''
 
 """
 Make a pre-edited file reference that can be inputted back into auto-editor.
